@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::App::CmdLine;
-$Games::Solitaire::Verify::App::CmdLine::VERSION = '0.1800';
+$Games::Solitaire::Verify::App::CmdLine::VERSION = '0.1900';
 use strict;
 use warnings;
 
@@ -16,65 +16,71 @@ __PACKAGE__->mk_acc_ref(
     [
         qw(
             _filename
+            _max_rank
             _variant_params
-        )
+            )
     ]
 );
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $argv = $args->{'argv'};
 
     my $variant_map = Games::Solitaire::Verify::VariantsMap->new();
 
     my $variant_params = $variant_map->get_variant_by_id("freecell");
+    my $max_rank       = 13;
 
     GetOptionsFromArray(
         $argv,
         'g|game|variant=s' => sub {
-            my (undef, $game) = @_;
+            my ( undef, $game ) = @_;
 
             $variant_params = $variant_map->get_variant_by_id($game);
 
-            if (!defined($variant_params))
+            if ( !defined($variant_params) )
             {
                 die "Unknown variant '$game'!\n";
             }
         },
         'freecells-num=i' => sub {
-            my (undef, $n) = @_;
+            my ( undef, $n ) = @_;
             $variant_params->num_freecells($n);
         },
         'stacks-num=i' => sub {
-            my (undef, $n) = @_;
+            my ( undef, $n ) = @_;
             $variant_params->num_columns($n);
         },
         'decks-num=i' => sub {
-            my (undef, $n) = @_;
+            my ( undef, $n ) = @_;
 
-            if (! ( ($n == 1) || ($n == 2) ) )
+            if ( !( ( $n == 1 ) || ( $n == 2 ) ) )
             {
                 die "Decks should be 1 or 2.";
             }
 
             $variant_params->num_decks($n);
         },
-        'sequences-are-built-by=s' => sub {
-            my (undef, $val) = @_;
+        'max-rank=i' => sub {
+            my ( undef, $n ) = @_;
 
-            my %seqs_build_by =
-            (
-                (map { $_ => $_ }
-                    (qw(alt_color suit rank))
-                ),
+            $max_rank = $n;
+
+            return;
+        },
+        'sequences-are-built-by=s' => sub {
+            my ( undef, $val ) = @_;
+
+            my %seqs_build_by = (
+                ( map { $_ => $_ } (qw(alt_color suit rank)) ),
                 "alternate_color" => "alt_color",
             );
 
             my $proc_val = $seqs_build_by{$val};
 
-            if (! defined($proc_val))
+            if ( !defined($proc_val) )
             {
                 die "Unknown sequences-are-built-by '$val'!";
             }
@@ -82,12 +88,12 @@ sub _init
             $variant_params->seqs_build_by($proc_val);
         },
         'empty-stacks-filled-by=s' => sub {
-            my (undef, $val) = @_;
+            my ( undef, $val ) = @_;
 
             my %empty_stacks_filled_by_map =
-            (map { $_ => 1 } (qw(kings any none)));
+                ( map { $_ => 1 } (qw(kings any none)) );
 
-            if (! exists($empty_stacks_filled_by_map{$val}))
+            if ( !exists( $empty_stacks_filled_by_map{$val} ) )
             {
                 die "Unknown empty stacks filled by '$val'!";
             }
@@ -95,29 +101,29 @@ sub _init
             $variant_params->empty_stacks_filled_by($val);
         },
         'sequence-move=s' => sub {
-            my (undef, $val) = @_;
+            my ( undef, $val ) = @_;
 
-            my %seq_moves = (map { $_ => 1 } (qw(limited unlimited)));
+            my %seq_moves = ( map { $_ => 1 } (qw(limited unlimited)) );
 
-            if (! exists ($seq_moves{$val}) )
+            if ( !exists( $seq_moves{$val} ) )
             {
                 die "Unknown sequence move '$val'!";
             }
 
             $variant_params->sequence_move($val);
         },
-    )
-        or die "Cannot process command line arguments";
+    ) or die "Cannot process command line arguments";
 
     my $filename = shift(@$argv);
 
-    if (!defined($filename))
+    if ( !defined($filename) )
     {
         $filename = "-";
     }
 
     $self->_variant_params($variant_params);
     $self->_filename($filename);
+    $self->_max_rank($max_rank);
 
     return;
 }
@@ -126,12 +132,12 @@ sub run
 {
     my $self = shift;
 
-    my $filename = $self->_filename();
+    my $filename       = $self->_filename();
     my $variant_params = $self->_variant_params();
 
     my $fh;
 
-    if ($filename eq "-")
+    if ( $filename eq "-" )
     {
         $fh = *STDIN;
     }
@@ -143,14 +149,15 @@ sub run
 
     my $solution = Games::Solitaire::Verify::Solution->new(
         {
-            input_fh => $fh,
-            variant => "custom",
+            max_rank       => scalar( $self->_max_rank ),
+            input_fh       => $fh,
+            variant        => "custom",
             variant_params => $variant_params,
         },
     );
 
     my $verdict = $solution->verify();
-    if (!$verdict)
+    if ( !$verdict )
     {
         print "Solution is OK.\n";
         exit(0);
@@ -178,7 +185,7 @@ command line app for verifying the solutions of Solitaire games.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 SYNOPSIS
 
@@ -191,7 +198,7 @@ solutions of Solitaire games.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 EXPORTS
 
