@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::App::CmdLine::From_Patsolve;
-$Games::Solitaire::Verify::App::CmdLine::From_Patsolve::VERSION = '0.1800';
+$Games::Solitaire::Verify::App::CmdLine::From_Patsolve::VERSION = '0.1900';
 use strict;
 use warnings;
 
@@ -25,13 +25,13 @@ __PACKAGE__->mk_acc_ref(
             _sol_filename
             _variant_params
             _buffer_ref
-        )
+            )
     ]
 );
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $argv = $args->{'argv'};
 
@@ -42,27 +42,27 @@ sub _init
     GetOptionsFromArray(
         $argv,
         'g|game|variant=s' => sub {
-            my (undef, $game) = @_;
+            my ( undef, $game ) = @_;
 
             $variant_params = $variant_map->get_variant_by_id($game);
 
-            if (!defined($variant_params))
+            if ( !defined($variant_params) )
             {
                 die "Unknown variant '$game'!\n";
             }
         },
         'freecells-num=i' => sub {
-            my (undef, $n) = @_;
+            my ( undef, $n ) = @_;
             $variant_params->num_freecells($n);
         },
         'stacks-num=i' => sub {
-            my (undef, $n) = @_;
+            my ( undef, $n ) = @_;
             $variant_params->num_columns($n);
         },
         'decks-num=i' => sub {
-            my (undef, $n) = @_;
+            my ( undef, $n ) = @_;
 
-            if (! ( ($n == 1) || ($n == 2) ) )
+            if ( !( ( $n == 1 ) || ( $n == 2 ) ) )
             {
                 die "Decks should be 1 or 2.";
             }
@@ -70,19 +70,16 @@ sub _init
             $variant_params->num_decks($n);
         },
         'sequences-are-built-by=s' => sub {
-            my (undef, $val) = @_;
+            my ( undef, $val ) = @_;
 
-            my %seqs_build_by =
-            (
-                (map { $_ => $_ }
-                    (qw(alt_color suit rank))
-                ),
+            my %seqs_build_by = (
+                ( map { $_ => $_ } (qw(alt_color suit rank)) ),
                 "alternate_color" => "alt_color",
             );
 
             my $proc_val = $seqs_build_by{$val};
 
-            if (! defined($proc_val))
+            if ( !defined($proc_val) )
             {
                 die "Unknown sequences-are-built-by '$val'!";
             }
@@ -90,12 +87,12 @@ sub _init
             $variant_params->seqs_build_by($proc_val);
         },
         'empty-stacks-filled-by=s' => sub {
-            my (undef, $val) = @_;
+            my ( undef, $val ) = @_;
 
             my %empty_stacks_filled_by_map =
-            (map { $_ => 1 } (qw(kings any none)));
+                ( map { $_ => 1 } (qw(kings any none)) );
 
-            if (! exists($empty_stacks_filled_by_map{$val}))
+            if ( !exists( $empty_stacks_filled_by_map{$val} ) )
             {
                 die "Unknown empty stacks filled by '$val'!";
             }
@@ -103,30 +100,29 @@ sub _init
             $variant_params->empty_stacks_filled_by($val);
         },
         'sequence-move=s' => sub {
-            my (undef, $val) = @_;
+            my ( undef, $val ) = @_;
 
-            my %seq_moves = (map { $_ => 1 } (qw(limited unlimited)));
+            my %seq_moves = ( map { $_ => 1 } (qw(limited unlimited)) );
 
-            if (! exists ($seq_moves{$val}) )
+            if ( !exists( $seq_moves{$val} ) )
             {
                 die "Unknown sequence move '$val'!";
             }
 
             $variant_params->sequence_move($val);
         },
-    )
-        or die "Cannot process command line arguments";
+    ) or die "Cannot process command line arguments";
 
     my $filename = shift(@$argv);
 
-    if (!defined($filename))
+    if ( !defined($filename) )
     {
         $filename = "-";
     }
 
     my $sol_filename = shift(@$argv);
 
-    if (!defined($sol_filename))
+    if ( !defined($sol_filename) )
     {
         die "Solution filename not specified.";
     }
@@ -136,16 +132,16 @@ sub _init
     $self->_sol_filename($sol_filename);
 
     my $s = '';
-    $self->_buffer_ref(\$s);
+    $self->_buffer_ref( \$s );
 
     return;
 }
 
 sub _append
 {
-    my ($self, $text) = @_;
+    my ( $self, $text ) = @_;
 
-    ${$self->_buffer_ref} .= $text;
+    ${ $self->_buffer_ref } .= $text;
 
     return;
 }
@@ -154,7 +150,7 @@ sub _get_buffer
 {
     my ($self) = @_;
 
-    return ${$self->_buffer_ref};
+    return ${ $self->_buffer_ref };
 }
 
 sub _slurp
@@ -179,8 +175,8 @@ sub _read_initial_state
     $self->_st(
         Games::Solitaire::Verify::State::LaxParser->new(
             {
-                string => scalar(_slurp($self->_filename)),
-                variant => 'custom',
+                string           => scalar( _slurp( $self->_filename ) ),
+                variant          => 'custom',
                 'variant_params' => $self->_variant_params(),
             }
         )
@@ -197,24 +193,22 @@ sub _out_running_state
 {
     my ($self) = @_;
 
-    $self->_append(
-        $self->_st->to_string(). "\n\n====================\n\n"
-    );
+    $self->_append( $self->_st->to_string() . "\n\n====================\n\n" );
 
     return;
 }
 
 sub _perform_and_output_move
 {
-    my ($self, $move_s) = @_;
+    my ( $self, $move_s ) = @_;
 
-    $self->_append( "$move_s\n\n");
+    $self->_append("$move_s\n\n");
 
     $self->_st->verify_and_perform_move(
         Games::Solitaire::Verify::Move->new(
             {
                 fcs_string => $move_s,
-                game => $self->_st->_variant(),
+                game       => $self->_st->_variant(),
             },
         )
     );
@@ -225,113 +219,123 @@ sub _perform_and_output_move
 
 sub _find_col_card
 {
-    my ($self, $card_s) = @_;
+    my ( $self, $card_s ) = @_;
 
-    return firstidx {
+    return firstidx
+    {
         my $col = $self->_st->get_column($_);
-        ($col->len == 0) ? 0 : $col->top->fast_s eq $card_s
-    } (0 .. $self->_st->num_columns - 1);
+        ( $col->len == 0 ) ? 0 : $col->top->fast_s eq $card_s
+    }
+    ( 0 .. $self->_st->num_columns - 1 );
 }
 
 sub _find_empty_col
 {
     my ($self) = @_;
 
-    return firstidx {
+    return firstidx
+    {
         $self->_st->get_column($_)->len == 0
-    } (0 .. $self->_st->num_columns - 1);
+    }
+    ( 0 .. $self->_st->num_columns - 1 );
 }
 
 sub _find_fc_card
 {
-    my ($self, $card_s) = @_;
-    my $dest_fc_idx = firstidx {
+    my ( $self, $card_s ) = @_;
+    my $dest_fc_idx = firstidx
+    {
         my $card = $self->_st->get_freecell($_);
-        defined ($card) ? ($card->fast_s eq $card_s) : 0;
-    } (0 .. $self->_st->num_freecells - 1);
+        defined($card) ? ( $card->fast_s eq $card_s ) : 0;
+    }
+    ( 0 .. $self->_st->num_freecells - 1 );
 }
 
 sub _find_card_src_string
 {
-    my ($self, $src_card_s) = @_;
+    my ( $self, $src_card_s ) = @_;
 
     my $src_col_idx = $self->_find_col_card($src_card_s);
+
     # TODO : try to find a freecell card.
-    if ($src_col_idx < 0)
+    if ( $src_col_idx < 0 )
     {
         my $src_fc_idx = $self->_find_fc_card($src_card_s);
-        if ($src_fc_idx < 0)
+        if ( $src_fc_idx < 0 )
         {
             die "Cannot find card <$src_card_s>.";
         }
-        return ("a card", "freecell $src_fc_idx");
+        return ( "a card", "freecell $src_fc_idx" );
     }
     else
     {
-        return ("1 cards", "stack $src_col_idx");
+        return ( "1 cards", "stack $src_col_idx" );
     }
 }
 
 sub _perform_move
 {
-    my ($self, $move_line) = @_;
+    my ( $self, $move_line ) = @_;
 
-    if (my ($src_card_s) = $move_line =~ /\A(.[HCDS]) to temp\z/)
+    if ( my ($src_card_s) = $move_line =~ /\A(.[HCDS]) to temp\z/ )
     {
         my $src_col_idx = $self->_find_col_card($src_card_s);
-        if ($src_col_idx < 0)
+        if ( $src_col_idx < 0 )
         {
             die "Cannot find card.";
         }
 
-        my $dest_fc_idx = firstidx {
-            ! defined ($self->_st->get_freecell($_))
-        } (0 .. $self->_st->num_freecells - 1);
+        my $dest_fc_idx = firstidx
+        {
+            !defined( $self->_st->get_freecell($_) )
+        }
+        ( 0 .. $self->_st->num_freecells - 1 );
 
-        if ($dest_fc_idx < 0)
+        if ( $dest_fc_idx < 0 )
         {
             die "No empty freecell.";
         }
 
         $self->_perform_and_output_move(
-            sprintf("Move a card from stack %d to freecell %d", $src_col_idx, $dest_fc_idx,),
+            sprintf(
+                "Move a card from stack %d to freecell %d",
+                $src_col_idx, $dest_fc_idx,
+            ),
         );
 
     }
-    elsif (($src_card_s) = $move_line =~ /\A(.[HCDS]) out\z/)
+    elsif ( ($src_card_s) = $move_line =~ /\A(.[HCDS]) out\z/ )
     {
         my @src_s = $self->_find_card_src_string($src_card_s);
         $self->_perform_and_output_move(
-            sprintf("Move a card from %s to the foundations", $src_s[1]),
+            sprintf( "Move a card from %s to the foundations", $src_s[1] ),
         );
     }
-    elsif (($src_card_s) = $move_line =~ /\A(.[HCDS]) to empty pile\z/)
+    elsif ( ($src_card_s) = $move_line =~ /\A(.[HCDS]) to empty pile\z/ )
     {
         my $dest_col_idx = $self->_find_empty_col;
-        if ($dest_col_idx < 0)
+        if ( $dest_col_idx < 0 )
         {
             die "Cannot find empty col.";
         }
         my @src_s = $self->_find_card_src_string($src_card_s);
 
         $self->_perform_and_output_move(
-            sprintf("Move %s from %s to stack %d", @src_s, $dest_col_idx),
+            sprintf( "Move %s from %s to stack %d", @src_s, $dest_col_idx ),
         );
     }
-    elsif (($src_card_s, (my $dest_card_s)) = $move_line =~ /\A(.[HCDS]) to (.[HCDS])\z/)
+    elsif ( ( $src_card_s, ( my $dest_card_s ) ) =
+        $move_line =~ /\A(.[HCDS]) to (.[HCDS])\z/ )
     {
         my $dest_col_idx = $self->_find_col_card($dest_card_s);
-        if ($dest_col_idx < 0)
+        if ( $dest_col_idx < 0 )
         {
             die "Cannot find card <$dest_card_s>.";
         }
 
         my @src_s = $self->_find_card_src_string($src_card_s);
         $self->_perform_and_output_move(
-            sprintf("Move %s from %s to stack %d",
-                @src_s, $dest_col_idx
-            )
-        );
+            sprintf( "Move %s from %s to stack %d", @src_s, $dest_col_idx ) );
     }
     else
     {
@@ -347,7 +351,7 @@ sub _process_main
 
     open my $in_fh, '<', $self->_sol_filename;
 
-    while (my $l = <$in_fh>)
+    while ( my $l = <$in_fh> )
     {
         chomp($l);
         $self->_perform_move($l);
@@ -386,7 +390,7 @@ converting from patsolve solutions to fc-solve ones.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 SYNOPSIS
 
@@ -399,7 +403,7 @@ converting from patsolve solutions to fc-solve ones.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 METHODS
 
