@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::Column;
-$Games::Solitaire::Verify::Column::VERSION = '0.1800';
+$Games::Solitaire::Verify::Column::VERSION = '0.1900';
 use warnings;
 use strict;
 
@@ -9,35 +9,33 @@ use parent 'Games::Solitaire::Verify::Base';
 use Games::Solitaire::Verify::Exception;
 use Games::Solitaire::Verify::Card;
 
-__PACKAGE__->mk_acc_ref([qw(
-    _cards
-    _s
-    )]);
+__PACKAGE__->mk_acc_ref(
+    [
+        qw(
+            _cards
+            _s
+            )
+    ]
+);
 
 
 sub _from_string
 {
-    my ($self, $str) = @_;
+    my ( $self, $str ) = @_;
 
-    if ($str !~ s{\A:(?: )?}{})
+    if ( $str !~ s{\A:(?: )?}{} )
     {
         Games::Solitaire::Verify::Exception::Parse::Column::Prefix->throw(
-            error => "String does not start with \": \"",
-        );
+            error => "String does not start with \": \"", );
     }
 
     # Ignore trailing whitespace, so we don't have -1.
-    my @cards = split(/ +/, $str);
+    my @cards = split( / +/, $str );
 
     $self->_cards(
         [
-            map
-            {
-                Games::Solitaire::Verify::Card->new(
-                    {string => $_ }
-                )
-            }
-            @cards
+            map { Games::Solitaire::Verify::Card->new( { string => $_ } ) }
+                @cards
         ]
     );
 
@@ -48,22 +46,22 @@ sub _from_string
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    if (exists($args->{string}))
+    if ( exists( $args->{string} ) )
     {
-        return $self->_from_string($args->{string});
+        return $self->_from_string( $args->{string} );
     }
-    elsif (exists($args->{cards}))
+    elsif ( exists( $args->{cards} ) )
     {
-        $self->_cards($args->{cards});
+        $self->_cards( $args->{cards} );
 
         $self->_recalc;
         return;
     }
     else
     {
-        die "Cannot init - no 'string' or 'cards' specified."
+        die "Cannot init - no 'string' or 'cards' specified.";
     }
 }
 
@@ -72,14 +70,14 @@ sub len
 {
     my $self = shift;
 
-    return scalar(@{$self->_cards()});
+    return scalar( @{ $self->_cards() } );
 }
 
 
 sub pos
 {
     my $self = shift;
-    my $idx = shift;
+    my $idx  = shift;
 
     return $self->_cards->[$idx];
 }
@@ -99,7 +97,7 @@ sub clone
 
     my $new_col = Games::Solitaire::Verify::Column->new(
         {
-            cards => [ map { $_->clone() } @{$self->_cards()} ],
+            cards => [ map { $_->clone() } @{ $self->_cards() } ],
         }
     );
 
@@ -109,8 +107,8 @@ sub clone
 
 sub append_cards
 {
-    my ($S, $c) = @_;
-    push @{$S->_cards()}, @$c;
+    my ( $S, $c ) = @_;
+    push @{ $S->_cards() }, @$c;
     $S->_recalc;
     return;
 }
@@ -118,19 +116,19 @@ sub append_cards
 
 sub append
 {
-    my ($self, $more_cards) = @_;
+    my ( $self, $more_cards ) = @_;
 
     my $more_copy = $more_cards->clone();
 
-    return $self->append_cards($more_copy->_cards);
+    return $self->append_cards( $more_copy->_cards );
 }
 
 
 sub push
 {
-    my ($self, $card) = @_;
+    my ( $self, $card ) = @_;
 
-    push @{$self->_cards()}, $card;
+    push @{ $self->_cards() }, $card;
 
     $self->_recalc;
 
@@ -142,7 +140,7 @@ sub pop
 {
     my $self = shift;
 
-    my $card = pop(@{$self->_cards()});
+    my $card = pop( @{ $self->_cards() } );
 
     $self->_recalc;
 
@@ -152,9 +150,9 @@ sub pop
 
 sub popN
 {
-    my ($S, $c) = @_;
+    my ( $S, $c ) = @_;
 
-    my @r = splice(@{$S->_cards()}, -$c);
+    my @r = splice( @{ $S->_cards() }, -$c );
 
     $S->_recalc;
 
@@ -167,14 +165,7 @@ sub _recalc
     my $self = shift;
 
     $self->_s(
-        join(' ',
-            ':',
-            (map
-                { $_->fast_s() }
-                @{$self->_cards()}
-            )
-        )
-    );
+        join( ' ', ':', ( map { $_->fast_s() } @{ $self->_cards() } ) ) );
 
     return;
 }
@@ -184,7 +175,7 @@ sub to_string
     return shift->_s;
 }
 
-1; # End of Games::Solitaire::Verify::Column
+1;    # End of Games::Solitaire::Verify::Column
 
 __END__
 
@@ -199,7 +190,7 @@ columns that are composed of a sequence of cards.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 SYNOPSIS
 
@@ -219,7 +210,7 @@ version 0.1800
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 METHODS
 
