@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::Exception;
-$Games::Solitaire::Verify::Exception::VERSION = '0.1800';
+$Games::Solitaire::Verify::Exception::VERSION = '0.1900';
 use strict;
 use warnings;
 
@@ -7,123 +7,127 @@ use warnings;
 use Exception::Class (
     'Games::Solitaire::Verify::Exception',
     'Games::Solitaire::Verify::Exception::Parse' =>
-    { isa => "Games::Solitaire::Verify::Exception", },
+        { isa => "Games::Solitaire::Verify::Exception", },
     'Games::Solitaire::Verify::Exception::Parse::FCS' =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse", },
     'Games::Solitaire::Verify::Exception::Parse::Card' =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse", },
     'Games::Solitaire::Verify::Exception::Parse::Card::UnknownRank' =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse::Card", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse::Card", },
     'Games::Solitaire::Verify::Exception::Parse::Card::UnknownSuit' =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse::Card", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse::Card", },
     'Games::Solitaire::Verify::Exception::Parse::Column' =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse", },
     'Games::Solitaire::Verify::Exception::Parse::Column::Prefix' =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse::Column", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse::Column", },
     'Games::Solitaire::Verify::Exception::Parse::State' =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse", },
     "Games::Solitaire::Verify::Exception::Parse::State::Foundations" =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse::State", },
+        { isa => "Games::Solitaire::Verify::Exception::Parse::State", },
     "Games::Solitaire::Verify::Exception::Parse::State::Freecells" =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse::State", },
-    "Games::Solitaire::Verify::Exception::Parse::State::Column" =>
-    { isa => "Games::Solitaire::Verify::Exception::Parse::State",
-      fields => ["index"],
+        { isa => "Games::Solitaire::Verify::Exception::Parse::State", },
+    "Games::Solitaire::Verify::Exception::Parse::State::Column" => {
+        isa    => "Games::Solitaire::Verify::Exception::Parse::State",
+        fields => ["index"],
     },
-
-    "Games::Solitaire::Verify::Exception::VariantParams::Param" =>
-    {
-        isa => "Games::Solitaire::Verify::Exception",
+    "Games::Solitaire::Verify::Exception::State" => {
+        isa    => "Games::Solitaire::Verify::Exception",
+        fields => ["cards"],
+    },
+    "Games::Solitaire::Verify::Exception::State::ExtraCards" => {
+        isa => "Games::Solitaire::Verify::Exception::State",
+    },
+    "Games::Solitaire::Verify::Exception::State::MissingCards" => {
+        isa => "Games::Solitaire::Verify::Exception::State",
+    },
+    "Games::Solitaire::Verify::Exception::State::TooHighRank" => {
+        isa => "Games::Solitaire::Verify::Exception::State",
+    },
+    "Games::Solitaire::Verify::Exception::VariantParams::Param" => {
+        isa    => "Games::Solitaire::Verify::Exception",
         fields => ["value"],
     },
-    "Games::Solitaire::Verify::Exception::VariantParams::Param::NumDecks" =>
-    {
+    "Games::Solitaire::Verify::Exception::VariantParams::Param::NumDecks" => {
         isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
     },
-    "Games::Solitaire::Verify::Exception::VariantParams::Param::EmptyStacksFill" =>
-    {
+    "Games::Solitaire::Verify::Exception::VariantParams::Param::EmptyStacksFill"
+        => {
+        isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
+        },
+    "Games::Solitaire::Verify::Exception::VariantParams::Param::Stacks" => {
         isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
     },
-    "Games::Solitaire::Verify::Exception::VariantParams::Param::Stacks" =>
-    {
+    "Games::Solitaire::Verify::Exception::VariantParams::Param::Freecells" => {
         isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
     },
-    "Games::Solitaire::Verify::Exception::VariantParams::Param::Freecells" =>
-    {
-        isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
-    },
-    "Games::Solitaire::Verify::Exception::VariantParams::Param::SeqMove" =>
-    {
+    "Games::Solitaire::Verify::Exception::VariantParams::Param::SeqMove" => {
         isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
     },
     "Games::Solitaire::Verify::Exception::VariantParams::Param::SeqBuildBy" =>
-    {
+        {
         isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
-    },
-    "Games::Solitaire::Verify::Exception::VariantParams::Param::Rules" =>
-    {
+        },
+    "Games::Solitaire::Verify::Exception::VariantParams::Param::Rules" => {
         isa => "Games::Solitaire::Verify::Exception::VariantParams::Param",
     },
 
-    'Games::Solitaire::Verify::Exception::Variant' =>
-    { isa => "Games::Solitaire::Verify::Exception",
-      fields => ["variant"],
+    'Games::Solitaire::Verify::Exception::Variant' => {
+        isa    => "Games::Solitaire::Verify::Exception",
+        fields => ["variant"],
     },
     'Games::Solitaire::Verify::Exception::Variant::Unknown' =>
-    { isa => "Games::Solitaire::Verify::Exception::Variant", },
-    'Games::Solitaire::Verify::Exception::VerifyMove' =>
-    { isa => "Games::Solitaire::Verify::Exception",
+        { isa => "Games::Solitaire::Verify::Exception::Variant", },
+    'Games::Solitaire::Verify::Exception::VerifyMove' => {
+        isa    => "Games::Solitaire::Verify::Exception",
         fields => ["problem"],
     },
-    'Games::Solitaire::Verify::Exception::Move' =>
-    { isa => "Games::Solitaire::Verify::Exception",
+    'Games::Solitaire::Verify::Exception::Move' => {
+        isa    => "Games::Solitaire::Verify::Exception",
         fields => ["move"],
     },
-   'Games::Solitaire::Verify::Exception::Move::Variant::Unsupported' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move", },
+    'Games::Solitaire::Verify::Exception::Move::Variant::Unsupported' =>
+        { isa => "Games::Solitaire::Verify::Exception::Move", },
     'Games::Solitaire::Verify::Exception::Move::NotEnoughEmpties' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move", },
+        { isa => "Games::Solitaire::Verify::Exception::Move", },
     'Games::Solitaire::Verify::Exception::Move::Src' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move", },
+        { isa => "Games::Solitaire::Verify::Exception::Move", },
     'Games::Solitaire::Verify::Exception::Move::Src::Col' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Src", },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Src", },
     'Games::Solitaire::Verify::Exception::Move::Src::Col::NoCards' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Src::Col", },
-    'Games::Solitaire::Verify::Exception::Move::Src::Col::NonSequence' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Src::Col",
-      fields => [qw(pos)],
+        { isa => "Games::Solitaire::Verify::Exception::Move::Src::Col", },
+    'Games::Solitaire::Verify::Exception::Move::Src::Col::NonSequence' => {
+        isa    => "Games::Solitaire::Verify::Exception::Move::Src::Col",
+        fields => [qw(pos)],
     },
     'Games::Solitaire::Verify::Exception::Move::Src::Col::NotEnoughCards' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Src::Col", },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Src::Col", },
     'Games::Solitaire::Verify::Exception::Move::Src::Col::NotTrueSeq' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Src::Col", },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Src::Col", },
     'Games::Solitaire::Verify::Exception::Move::Src::Freecell::Empty' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Src", },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Src", },
     'Games::Solitaire::Verify::Exception::Move::Dest' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move", },
+        { isa => "Games::Solitaire::Verify::Exception::Move", },
     'Games::Solitaire::Verify::Exception::Move::Dest::Foundation' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Dest", },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Dest", },
     'Games::Solitaire::Verify::Exception::Move::Dest::Freecell' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Dest", },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Dest", },
     'Games::Solitaire::Verify::Exception::Move::Dest::Col' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Dest", },
-    'Games::Solitaire::Verify::Exception::Move::Dest::Col::NonMatchSuits' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Dest::Col",
-      fields => [qw(seq_build_by)],
-      },
-    'Games::Solitaire::Verify::Exception::Move::Dest::Col::OnlyKingsCanFillEmpty' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Dest::Col",
-      },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Dest", },
+    'Games::Solitaire::Verify::Exception::Move::Dest::Col::NonMatchSuits' => {
+        isa    => "Games::Solitaire::Verify::Exception::Move::Dest::Col",
+        fields => [qw(seq_build_by)],
+    },
+'Games::Solitaire::Verify::Exception::Move::Dest::Col::OnlyKingsCanFillEmpty'
+        => { isa => "Games::Solitaire::Verify::Exception::Move::Dest::Col", },
     'Games::Solitaire::Verify::Exception::Move::Dest::Col::RankMismatch' =>
-    { isa => "Games::Solitaire::Verify::Exception::Move::Dest::Col",
-      },
+        { isa => "Games::Solitaire::Verify::Exception::Move::Dest::Col", },
 
-      );
+);
 
 
 
 
-1; # End of Games::Solitaire::Verify::Exception
+1;    # End of Games::Solitaire::Verify::Exception
 
 __END__
 
@@ -138,7 +142,7 @@ classes for G::S::Verify.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 SYNOPSIS
 
@@ -150,7 +154,7 @@ These are L<Exception:Class> exceptions for L<Games::Solitaire::Verify> .
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 FUNCTIONS
 
