@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::Move;
-$Games::Solitaire::Verify::Move::VERSION = '0.1800';
+$Games::Solitaire::Verify::Move::VERSION = '0.1900';
 use warnings;
 use strict;
 
@@ -8,21 +8,25 @@ use parent 'Games::Solitaire::Verify::Base';
 
 use Games::Solitaire::Verify::Exception;
 
-__PACKAGE__->mk_acc_ref([qw(
-    source_type
-    dest_type
-    source
-    dest
-    num_cards
-    _game
-    )]);
+__PACKAGE__->mk_acc_ref(
+    [
+        qw(
+            source_type
+            dest_type
+            source
+            dest
+            num_cards
+            _game
+            )
+    ]
+);
 
 
 sub _from_fcs_string
 {
-    my ($self, $str) = @_;
+    my ( $self, $str ) = @_;
 
-    if ($str =~ m{\AMove a card from stack (\d+) to the foundations\z})
+    if ( $str =~ m{\AMove a card from stack (\d+) to the foundations\z} )
     {
         my $source = $1;
 
@@ -31,7 +35,7 @@ sub _from_fcs_string
 
         $self->source($source);
     }
-    elsif ($str =~ m{\AMove a card from freecell (\d+) to the foundations\z})
+    elsif ( $str =~ m{\AMove a card from freecell (\d+) to the foundations\z} )
     {
         my $source = $1;
 
@@ -40,9 +44,9 @@ sub _from_fcs_string
 
         $self->source($source);
     }
-    elsif ($str =~ m{\AMove a card from freecell (\d+) to stack (\d+)\z})
+    elsif ( $str =~ m{\AMove a card from freecell (\d+) to stack (\d+)\z} )
     {
-        my ($source, $dest) = ($1, $2);
+        my ( $source, $dest ) = ( $1, $2 );
 
         $self->source_type("freecell");
         $self->dest_type("stack");
@@ -50,9 +54,9 @@ sub _from_fcs_string
         $self->source($source);
         $self->dest($dest);
     }
-    elsif ($str =~ m{\AMove a card from stack (\d+) to freecell (\d+)\z})
+    elsif ( $str =~ m{\AMove a card from stack (\d+) to freecell (\d+)\z} )
     {
-        my ($source, $dest) = ($1, $2);
+        my ( $source, $dest ) = ( $1, $2 );
 
         $self->source_type("stack");
         $self->dest_type("freecell");
@@ -60,9 +64,9 @@ sub _from_fcs_string
         $self->source($source);
         $self->dest($dest);
     }
-    elsif ($str =~ m{\AMove (\d+) cards from stack (\d+) to stack (\d+)\z})
+    elsif ( $str =~ m{\AMove (\d+) cards from stack (\d+) to stack (\d+)\z} )
     {
-        my ($num_cards, $source, $dest) = ($1, $2, $3);
+        my ( $num_cards, $source, $dest ) = ( $1, $2, $3 );
 
         $self->source_type("stack");
         $self->dest_type("stack");
@@ -71,7 +75,8 @@ sub _from_fcs_string
         $self->dest($dest);
         $self->num_cards($num_cards);
     }
-    elsif ($str =~ m{\AMove the sequence on top of Stack (\d+) to the foundations\z})
+    elsif ( $str =~
+        m{\AMove the sequence on top of Stack (\d+) to the foundations\z} )
     {
         my $source = $1;
 
@@ -83,25 +88,24 @@ sub _from_fcs_string
     else
     {
         Games::Solitaire::Verify::Exception::Parse::FCS->throw(
-            error => "Cannot parse 'FCS' String",
-        );
+            error => "Cannot parse 'FCS' String", );
     }
 }
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    $self->_game($args->{game});
+    $self->_game( $args->{game} );
 
-    if (exists($args->{fcs_string}))
+    if ( exists( $args->{fcs_string} ) )
     {
-        return $self->_from_fcs_string($args->{fcs_string});
+        return $self->_from_fcs_string( $args->{fcs_string} );
     }
 }
 
 
-1; # End of Games::Solitaire::Verify::Move
+1;    # End of Games::Solitaire::Verify::Move
 
 __END__
 
@@ -116,7 +120,7 @@ Solitaire move.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 SYNOPSIS
 
@@ -131,7 +135,7 @@ version 0.1800
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 FUNCTIONS
 
