@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::Solution;
-$Games::Solitaire::Verify::Solution::VERSION = '0.1800';
+$Games::Solitaire::Verify::Solution::VERSION = '0.1900';
 use warnings;
 use strict;
 
@@ -17,7 +17,7 @@ use Games::Solitaire::Verify::State;
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     $self->SUPER::_init($args);
 
@@ -33,43 +33,42 @@ sub _read_state
 
     my $line = $self->_l();
 
-    if ($line ne "\n")
+    if ( $line ne "\n" )
     {
         die "Non empty line before state";
     }
 
     my $str = "";
 
-    while (($line = $self->_l()) && ($line ne "\n"))
+    while ( ( $line = $self->_l() ) && ( $line ne "\n" ) )
     {
         $str .= $line;
     }
 
-
-    if (!defined($self->_st()))
+    if ( !defined( $self->_st() ) )
     {
         $self->_st(
             Games::Solitaire::Verify::State->new(
                 {
                     string => $str,
-                    @{$self->_V},
+                    @{ $self->_V },
                 }
             )
         );
     }
     else
     {
-        if ($self->_st()->to_string() ne $str)
+        if ( $self->_st()->to_string() ne $str )
         {
             die "States don't match";
         }
     }
 
-    while (defined($line = $self->_l()) && ($line eq "\n"))
+    while ( defined( $line = $self->_l() ) && ( $line eq "\n" ) )
     {
     }
 
-    if ($line !~ m{\A={3,}\n\z})
+    if ( $line !~ m{\A={3,}\n\z} )
     {
         die "No ======== separator";
     }
@@ -83,14 +82,14 @@ sub _read_move
 
     my $line = $self->_l();
 
-    if ($line ne "\n")
+    if ( $line ne "\n" )
     {
         die "No empty line before move";
     }
 
     $line = $self->_l();
 
-    if ($line eq "This game is solveable.\n")
+    if ( $line eq "This game is solveable.\n" )
     {
         $self->_reached_end(1);
 
@@ -99,10 +98,11 @@ sub _read_move
 
     chomp($line);
 
-    $self->_move(Games::Solitaire::Verify::Move->new(
+    $self->_move(
+        Games::Solitaire::Verify::Move->new(
             {
                 fcs_string => $line,
-                game => $self->_variant(),
+                game       => $self->_variant(),
             }
         )
     );
@@ -114,10 +114,10 @@ sub _apply_move
 {
     my $self = shift;
 
-    if (my $verdict = $self->_st()->verify_and_perform_move($self->_move()))
+    if ( my $verdict = $self->_st()->verify_and_perform_move( $self->_move() ) )
     {
         Games::Solitaire::Verify::Exception::VerifyMove->throw(
-            error => "Wrong Move",
+            error   => "Wrong Move",
             problem => $verdict,
         );
     }
@@ -126,7 +126,6 @@ sub _apply_move
 }
 
 
-
 sub verify
 {
     my $self = shift;
@@ -135,14 +134,15 @@ sub verify
 
         my $line = $self->_l();
 
-        if ($line !~ m{\A(-=)+-\n\z})
+        if ( $line !~ m{\A(-=)+-\n\z} )
         {
             die "Incorrect start";
         }
 
         $self->_read_state();
+        $self->_st->verify_contents( { max_rank => $self->_max_rank } );
 
-        while (!defined(scalar($self->_read_move())))
+        while ( !defined( scalar( $self->_read_move() ) ) )
         {
             $self->_apply_move();
             $self->_read_state();
@@ -150,12 +150,14 @@ sub verify
     };
 
     my $err;
-    if (! $@)
+    if ( !$@ )
     {
         # Do nothing - no exception was thrown.
     }
-    elsif ($err =
-        Exception::Class->caught('Games::Solitaire::Verify::Exception::VerifyMove'))
+    elsif (
+        $err = Exception::Class->caught(
+            'Games::Solitaire::Verify::Exception::VerifyMove')
+        )
     {
         return { error => $err, line_num => $self->_ln(), };
     }
@@ -168,7 +170,7 @@ sub verify
     return;
 }
 
-1; # End of Games::Solitaire::Verify::Solution
+1;    # End of Games::Solitaire::Verify::Solution
 
 __END__
 
@@ -183,7 +185,7 @@ of Freecell Solver (or a similar solve)
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 SYNOPSIS
 
@@ -217,7 +219,7 @@ version 0.1800
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 METHODS
 
@@ -231,6 +233,9 @@ If $variant is C<"custom">, then the constructor also requires a
 C<'variant_params'> key which should be a populated
 L<Games::Solitaire::Verify::VariantParams> object.
 
+One can specify a numeric C<'max_rank'> argument to be lower than 13
+(new in 0.1900).
+
 =head2 $solution->verify()
 
 Traverse the solution verifying it.
