@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::Solution::Base;
-$Games::Solitaire::Verify::Solution::Base::VERSION = '0.1800';
+$Games::Solitaire::Verify::Solution::Base::VERSION = '0.1900';
 use strict;
 use warnings;
 
@@ -10,16 +10,21 @@ use parent 'Games::Solitaire::Verify::Base';
 # "_st" is the "state" (or board/layout).
 # "_i" is input filehandle.
 # "_V" is short for variant arguments.
-__PACKAGE__->mk_acc_ref([qw(
-    _V
-    _i
-    _ln
-    _variant
-    _variant_params
-    _st
-    _move
-    _reached_end
-    )]);
+__PACKAGE__->mk_acc_ref(
+    [
+        qw(
+            _V
+            _i
+            _ln
+            _variant
+            _variant_params
+            _st
+            _max_rank
+            _move
+            _reached_end
+            )
+    ]
+);
 
 # _l is short for _get_line()
 sub _l
@@ -29,7 +34,7 @@ sub _l
     # We use this instead of the accessor for speed.
     $s->{_ln}++;
 
-    return shift(@{$s->{_i}});
+    return shift( @{ $s->{_i} } );
 }
 
 sub _calc_variant_args
@@ -39,8 +44,8 @@ sub _calc_variant_args
     return [
         variant => $self->_variant(),
         (
-            ($self->_variant eq 'custom')
-            ? ('variant_params' => $self->_variant_params())
+              ( $self->_variant eq 'custom' )
+            ? ( 'variant_params' => $self->_variant_params() )
             : ()
         )
     ];
@@ -48,29 +53,34 @@ sub _calc_variant_args
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
+    $self->_max_rank( exists( $args->{max_rank} ) ? $args->{max_rank} : 13 );
     $self->_i(
-        [ split /^/ms, do {
+        [
+            split /^/ms,
+            do
+            {
                 local $/;
-                my $t = readline($args->{input_fh});
+                my $t = readline( $args->{input_fh} );
                 $t =~ s/ +$//gms;
                 $t;
-            }
-    ]);
+                }
+        ]
+    );
     $self->_ln(0);
 
-    $self->_variant($args->{variant});
+    $self->_variant( $args->{variant} );
 
     $self->_variant_params(
-        $self->_variant eq 'custom'
+          $self->_variant eq 'custom'
         ? $args->{variant_params}
         : Games::Solitaire::Verify::VariantsMap->get_variant_by_id(
             $self->_variant()
         )
     );
 
-    $self->_V($self->_calc_variant_args());
+    $self->_V( $self->_calc_variant_args() );
 
     return;
 }
@@ -90,11 +100,11 @@ all Games::Solitaire::Verify::Solution::* classes.
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 AUTHOR
 
